"""Shared definitions"""

PROGRAMNAME = 'metaindexmanager'

ANY_SCOPE = 'any'
ALL_SCOPE = 'all'
DICTIONARY_SCOPE = 'dictionary'

PREF_BORDER = 'border'
DEFAULT_BORDER = 'full'
BORDER_FULL = 'full'
BORDER_MINIMAL = 'minimal'

PREF_DEFAULT_PANEL = 'default-panel'
DEFAULT_DEFAULT_PANEL = 'documents'

PREF_FIND_CASE_SENSITIVE = 'find-case-sensitive'
DEFAULT_FIND_CASE_SENSITIVE = 'no'
